@@ -36,7 +36,7 @@ PITCH_BEND = 0xE0
 # High resolution continuous controllers (MSB)
 
 BANK_SELECT = BANK_SELECT_MSB = 0x00
-MODULATION_WHEEL = MODULATION_WHEEL_MSB = 0x01
+MODULATION = MODULATION_WHEEL = MODULATION_WHEEL_MSB = 0x01
 BREATH_CONTROLLER = BREATH_CONTROLLER_MSB = 0x02
 FOOT_CONTROLLER = FOOT_CONTROLLER_MSB = 0x04
 PORTAMENTO_TIME = PORTAMENTO_TIME_MSB = 0x05
